@@ -63,6 +63,7 @@ type TemplateArgs struct {
 	MountType                       string
 	Disks                           []Disk
 	GuestInstallPrefix              string
+	UpgradePackages                 bool
 	Containerd                      Containerd
 	Networks                        []Network
 	SlirpNICName                    string
@@ -81,7 +82,9 @@ type TemplateArgs struct {
 	SkipDefaultDependencyResolution bool
 	VMType                          string
 	VSockPort                       int
+	VirtioPort                      string
 	Plain                           bool
+	TimeZone                        string
 }
 
 func ValidateTemplateArgs(args TemplateArgs) error {
