@@ -16,6 +16,9 @@ import (
 	"sync"
 	"time"
 
+	"google.golang.org/grpc/codes"
+	"google.golang.org/grpc/status"
+
 	"github.com/lima-vm/lima/pkg/driver"
 	"github.com/lima-vm/lima/pkg/driverutil"
 	"github.com/lima-vm/lima/pkg/networks"
@@ -58,7 +61,7 @@ type HostAgent struct {
 	virtioPort string
 
 	clientMu sync.RWMutex
-	client   guestagentclient.GuestAgentClient
+	client   *guestagentclient.GuestAgentClient
 
 	guestAgentAliveCh     chan struct{} // closed on establishing the connection
 	guestAgentAliveChOnce sync.Once
@@ -157,7 +160,7 @@ func New(instName string, stdout io.Writer, signalCh chan os.Signal, opts ...Opt
 	}
 	rules = append(rules, y.PortForwards...)
 	// Default forwards for all non-privileged ports from "127.0.0.1" and "::1"
-	rule := limayaml.PortForward{GuestIP: guestagentapi.IPv4loopback1}
+	rule := limayaml.PortForward{}
 	limayaml.FillPortForwardDefaults(&rule, inst.Dir)
 	rules = append(rules, rule)
 
@@ -510,13 +513,7 @@ sudo chown -R "${USER}" /run/host-services`
 		case <-a.guestAgentAliveCh:
 			// NOP
 		case <-time.After(time.Minute):
-			err := errors.New("guest agent does not seem to be running; port forwards will not work")
-			if *a.y.VMType == limayaml.WSL2 {
-				// geustagent is currently not available for WSL2: https://github.com/lima-vm/lima/issues/2025
-				logrus.Warn(err)
-			} else {
-				errs = append(errs, err)
-			}
+			errs = append(errs, errors.New("guest agent does not seem to be running; port forwards will not work"))
 		}
 	}
 	if err := a.waitForRequirements("final", a.finalRequirements()); err != nil {
@@ -563,7 +560,7 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		logrus.Debugf("Forwarding unix sockets")
 		for _, rule := range a.y.PortForwards {
 			if rule.GuestSocket != "" {
-				local := hostAddress(rule, guestagentapi.IPPort{})
+				local := hostAddress(rule, &guestagentapi.IPPort{})
 				_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, local, rule.GuestSocket, verbForward, rule.Reverse)
 			}
 		}
@@ -577,7 +574,7 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		var errs []error
 		for _, rule := range a.y.PortForwards {
 			if rule.GuestSocket != "" {
-				local := hostAddress(rule, guestagentapi.IPPort{})
+				local := hostAddress(rule, &guestagentapi.IPPort{})
 				// using ctx.Background() because ctx has already been cancelled
 				if err := forwardSSH(context.Background(), a.sshConfig, a.sshLocalPort, local, rule.GuestSocket, verbCancel, rule.Reverse); err != nil {
 					errs = append(errs, err)
@@ -591,6 +588,21 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		}
 		return errors.Join(errs...)
 	})
+
+	go func() {
+		if a.y.MountInotify != nil && *a.y.MountInotify {
+			if a.client == nil || !isGuestAgentSocketAccessible(ctx, a.client) {
+				if a.driver.ForwardGuestAgent() {
+					_ = forwardSSH(ctx, a.sshConfig, a.sshLocalPort, localUnix, remoteUnix, verbForward, false)
+				}
+			}
+			err := a.startInotify(ctx)
+			if err != nil {
+				logrus.WithError(err).Warn("failed to start inotify")
+			}
+		}
+	}()
+
 	for {
 		if a.client == nil || !isGuestAgentSocketAccessible(ctx, a.client) {
 			if a.driver.ForwardGuestAgent() {
@@ -601,11 +613,13 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 		if err == nil {
 			if err := a.processGuestAgentEvents(ctx, client); err != nil {
 				if !errors.Is(err, context.Canceled) {
-					logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly", err)
+					logrus.WithError(err).Warn("guest agent events closed unexpectedly")
 				}
 			}
 		} else {
-			logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly", err)
+			if !strings.Contains(err.Error(), context.Canceled.Error()) {
+				logrus.WithError(err).Warn("connection to the guest agent was closed unexpectedly")
+			}
 		}
 		select {
 		case <-ctx.Done():
@@ -615,19 +629,19 @@ func (a *HostAgent) watchGuestAgentEvents(ctx context.Context) {
 	}
 }
 
-func isGuestAgentSocketAccessible(ctx context.Context, client guestagentclient.GuestAgentClient) bool {
+func isGuestAgentSocketAccessible(ctx context.Context, client *guestagentclient.GuestAgentClient) bool {
 	_, err := client.Info(ctx)
 	return err == nil
 }
 
-func (a *HostAgent) getOrCreateClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
+func (a *HostAgent) getOrCreateClient(ctx context.Context) (*guestagentclient.GuestAgentClient, error) {
 	a.clientMu.Lock()
 	defer a.clientMu.Unlock()
 	if a.client != nil && isGuestAgentSocketAccessible(ctx, a.client) {
 		return a.client, nil
 	}
 	var err error
-	a.client, err = a.createClient(ctx)
+	a.client, err = guestagentclient.NewGuestAgentClient(a.createConnection)
 	return a.client, err
 }
 
@@ -641,16 +655,7 @@ func (a *HostAgent) createConnection(ctx context.Context) (net.Conn, error) {
 	return conn, err
 }
 
-func (a *HostAgent) createClient(ctx context.Context) (guestagentclient.GuestAgentClient, error) {
-	conn, err := a.createConnection(ctx)
-	if err != nil {
-		return nil, err
-	}
-
-	return guestagentclient.NewGuestAgentClient(conn)
-}
-
-func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client guestagentclient.GuestAgentClient) error {
+func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client *guestagentclient.GuestAgentClient) error {
 	info, err := client.Info(ctx)
 	if err != nil {
 		return err
@@ -662,15 +667,18 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client guestage
 
 	logrus.Debugf("guest agent info: %+v", info)
 
-	onEvent := func(ev guestagentapi.Event) {
+	onEvent := func(ev *guestagentapi.Event) {
 		logrus.Debugf("guest agent event: %+v", ev)
 		for _, f := range ev.Errors {
 			logrus.Warnf("received error from the guest: %q", f)
 		}
-		a.portForwarder.OnEvent(ctx, ev, a.instSSHAddress)
+		a.portForwarder.OnEvent(ctx, ev)
 	}
 
 	if err := client.Events(ctx, onEvent); err != nil {
+		if status.Code(err) == codes.Canceled {
+			return context.Canceled
+		}
 		return err
 	}
 	return io.EOF
