@@ -17,7 +17,6 @@ import (
 	"github.com/sirupsen/logrus"
 	"golang.org/x/sys/cpu"
 
-	"github.com/lima-vm/lima/pkg/guestagent/api"
 	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/ptr"
@@ -37,8 +36,10 @@ const (
 	DefaultVirtiofsQueueSize int = 1024
 )
 
+var IPv4loopback1 = net.IPv4(127, 0, 0, 1)
+
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "1.7.3"
+	const nerdctlVersion = "1.7.5"
 	location := func(goos string, goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-" + goos + "-" + goarch + ".tar.gz"
 	}
@@ -46,12 +47,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("linux", "amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:f373aab78f04379557285590ee60ed953d12c9a60e08a52ba159004cf5e3d212",
+			Digest:   "sha256:adb246a4ef15b8f3d7eed4c6b61173014a6cf343e43ad95eae2087b454dcae5d",
 		},
 		{
 			Location: location("linux", "arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:4bf3e05c7203a1b86c84a506d022f7f4d2727143c8031cd5e4b78ef03f0fdcda",
+			Digest:   "sha256:ff38142440b4705e12782b7a71074849e712a42ccb69a11306343a8d9f81d8ab",
 		},
 		// No arm-v7
 		// No riscv64
@@ -147,6 +148,7 @@ func defaultGuestInstallPrefix() string {
 //   - DNS are picked from the highest priority where DNS is not empty.
 //   - CACertificates Files and Certs are uniquely appended in d, y, o order
 func FillDefault(y, d, o *LimaYAML, filePath string) {
+	instDir := filepath.Dir(filePath)
 	if y.VMType == nil {
 		y.VMType = d.VMType
 	}
@@ -393,7 +395,7 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		if provision.Mode == ProvisionModeDependency && provision.SkipDefaultDependencyResolution == nil {
 			provision.SkipDefaultDependencyResolution = ptr.Of(false)
 		}
-		if out, err := executeGuestTemplate(provision.Script); err == nil {
+		if out, err := executeGuestTemplate(provision.Script, instDir); err == nil {
 			provision.Script = out.String()
 		} else {
 			logrus.WithError(err).Warnf("Couldn't process provisioning script %q as a template", provision.Script)
@@ -462,7 +464,6 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	}
 
 	y.PortForwards = append(append(o.PortForwards, y.PortForwards...), d.PortForwards...)
-	instDir := filepath.Dir(filePath)
 	for i := range y.PortForwards {
 		FillPortForwardDefaults(&y.PortForwards[i], instDir)
 		// After defaults processing the singular HostPort and GuestPort values should not be used again.
@@ -578,6 +579,16 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		}
 	}
 
+	if y.MountInotify == nil {
+		y.MountInotify = d.MountInotify
+	}
+	if o.MountInotify != nil {
+		y.MountInotify = o.MountInotify
+	}
+	if y.MountInotify == nil {
+		y.MountInotify = ptr.Of(false)
+	}
+
 	// Combine all mounts; highest priority entry determines writable status.
 	// Only works for exact matches; does not normalize case or resolve symlinks.
 	mounts := make([]Mount, 0, len(d.Mounts)+len(y.Mounts)+len(o.Mounts))
@@ -745,12 +756,13 @@ func fixUpForPlainMode(y *LimaYAML) {
 	y.TimeZone = ptr.Of("")
 }
 
-func executeGuestTemplate(format string) (bytes.Buffer, error) {
+func executeGuestTemplate(format, instDir string) (bytes.Buffer, error) {
 	tmpl, err := template.New("").Parse(format)
 	if err == nil {
 		user, _ := osutil.LimaUser(false)
 		data := map[string]string{
 			"Home": fmt.Sprintf("/home/%s.linux", user.Username),
+			"Name": filepath.Base(instDir),
 			"UID":  user.Uid,
 			"User": user.Username,
 		}
@@ -794,11 +806,11 @@ func FillPortForwardDefaults(rule *PortForward, instDir string) {
 		if rule.GuestIPMustBeZero {
 			rule.GuestIP = net.IPv4zero
 		} else {
-			rule.GuestIP = api.IPv4loopback1
+			rule.GuestIP = IPv4loopback1
 		}
 	}
 	if rule.HostIP == nil {
-		rule.HostIP = api.IPv4loopback1
+		rule.HostIP = IPv4loopback1
 	}
 	if rule.GuestPortRange[0] == 0 && rule.GuestPortRange[1] == 0 {
 		if rule.GuestPort == 0 {
@@ -818,7 +830,7 @@ func FillPortForwardDefaults(rule *PortForward, instDir string) {
 		}
 	}
 	if rule.GuestSocket != "" {
-		if out, err := executeGuestTemplate(rule.GuestSocket); err == nil {
+		if out, err := executeGuestTemplate(rule.GuestSocket, instDir); err == nil {
 			rule.GuestSocket = out.String()
 		} else {
 			logrus.WithError(err).Warnf("Couldn't process guestSocket %q as a template", rule.GuestSocket)
@@ -838,7 +850,7 @@ func FillPortForwardDefaults(rule *PortForward, instDir string) {
 
 func FillCopyToHostDefaults(rule *CopyToHost, instDir string) {
 	if rule.GuestFile != "" {
-		if out, err := executeGuestTemplate(rule.GuestFile); err == nil {
+		if out, err := executeGuestTemplate(rule.GuestFile, instDir); err == nil {
 			rule.GuestFile = out.String()
 		} else {
 			logrus.WithError(err).Warnf("Couldn't process guest %q as a template", rule.GuestFile)
