@@ -10,7 +10,6 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
-	"github.com/lima-vm/lima/pkg/guestagent/api"
 	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/ptr"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
@@ -124,9 +123,9 @@ func TestFillDefault(t *testing.T) {
 	}
 
 	defaultPortForward := PortForward{
-		GuestIP:        api.IPv4loopback1,
+		GuestIP:        IPv4loopback1,
 		GuestPortRange: [2]int{1, 65535},
-		HostIP:         api.IPv4loopback1,
+		HostIP:         IPv4loopback1,
 		HostPortRange:  [2]int{1, 65535},
 		Proto:          TCP,
 		Reverse:        false,
@@ -227,6 +226,8 @@ func TestFillDefault(t *testing.T) {
 
 	expect.MountType = ptr.Of(NINEP)
 
+	expect.MountInotify = ptr.Of(false)
+
 	expect.Provision = y.Provision
 	expect.Provision[0].Mode = ProvisionModeSystem
 
@@ -386,10 +387,10 @@ func TestFillDefault(t *testing.T) {
 			net.ParseIP("1.1.1.1"),
 		},
 		PortForwards: []PortForward{{
-			GuestIP:        api.IPv4loopback1,
+			GuestIP:        IPv4loopback1,
 			GuestPort:      80,
 			GuestPortRange: [2]int{80, 80},
-			HostIP:         api.IPv4loopback1,
+			HostIP:         IPv4loopback1,
 			HostPort:       80,
 			HostPortRange:  [2]int{80, 80},
 			Proto:          TCP,
@@ -427,6 +428,7 @@ func TestFillDefault(t *testing.T) {
 		"default": d.HostResolver.Hosts["default"],
 	}
 	expect.MountType = ptr.Of(VIRTIOFS)
+	expect.MountInotify = ptr.Of(false)
 	expect.CACertificates.RemoveDefaults = ptr.Of(true)
 	expect.CACertificates.Certs = []string{
 		"-----BEGIN CERTIFICATE-----\nYOUR-ORGS-TRUSTED-CA-CERT\n-----END CERTIFICATE-----\n",
@@ -560,6 +562,7 @@ func TestFillDefault(t *testing.T) {
 				},
 			},
 		},
+		MountInotify: ptr.Of(true),
 		Provision: []Provision{
 			{
 				Script: "#!/bin/true",
@@ -588,10 +591,10 @@ func TestFillDefault(t *testing.T) {
 			net.ParseIP("2.2.2.2"),
 		},
 		PortForwards: []PortForward{{
-			GuestIP:        api.IPv4loopback1,
+			GuestIP:        IPv4loopback1,
 			GuestPort:      88,
 			GuestPortRange: [2]int{88, 88},
-			HostIP:         api.IPv4loopback1,
+			HostIP:         IPv4loopback1,
 			HostPort:       8080,
 			HostPortRange:  [2]int{8080, 8080},
 			Proto:          TCP,
@@ -637,6 +640,7 @@ func TestFillDefault(t *testing.T) {
 	expect.Mounts[0].Virtiofs.QueueSize = ptr.Of(2048)
 
 	expect.MountType = ptr.Of(NINEP)
+	expect.MountInotify = ptr.Of(true)
 
 	// o.Networks[1] is overriding the d.Networks[0].Lima entry for the "def0" interface
 	expect.Networks = append(append(d.Networks, y.Networks...), o.Networks[0])
