@@ -28,14 +28,20 @@ func DNSAddresses() ([]string, error) {
 }
 
 func proxyURL(proxy string, port interface{}) string {
-	if !strings.Contains(proxy, "://") {
+	if strings.Contains(proxy, "://") {
+		if portNumber, ok := port.(float64); ok && portNumber != 0 {
+			proxy = fmt.Sprintf("%s:%.0f", proxy, portNumber)
+		} else if portString, ok := port.(string); ok && portString != "" {
+			proxy = fmt.Sprintf("%s:%s", proxy, portString)
+		}
+	} else {
+		if portNumber, ok := port.(float64); ok && portNumber != 0 {
+			proxy = net.JoinHostPort(proxy, fmt.Sprintf("%.0f", portNumber))
+		} else if portString, ok := port.(string); ok && portString != "" {
+			proxy = net.JoinHostPort(proxy, portString)
+		}
 		proxy = "http://" + proxy
 	}
-	if portNumber, ok := port.(float64); ok && portNumber != 0 {
-		proxy = net.JoinHostPort(proxy, fmt.Sprintf("%.0f", portNumber))
-	} else if portString, ok := port.(string); ok && portString != "" {
-		proxy = net.JoinHostPort(proxy, portString)
-	}
 	return proxy
 }
 
