@@ -39,6 +39,7 @@ var knownYamlProperties = []string{
 	"Message",
 	"Mounts",
 	"MountType",
+	"MountInotify",
 	"Networks",
 	"OS",
 	"Plain",
@@ -49,6 +50,7 @@ var knownYamlProperties = []string{
 	"Rosetta",
 	"SSH",
 	"TimeZone",
+	"UpgradePackages",
 	"Video",
 	"VMType",
 }
